@@ -104,7 +104,7 @@ def train_from_folder(
     interpolation_num_steps = 100,
     save_frames = False,
     num_image_tiles = None,
-    trunc_psi = 0.75,
+    num_workers = None,
     multi_gpus = False,
     calculate_fid_every = None,
     calculate_fid_num_images = 12800,
@@ -128,13 +128,13 @@ def train_from_folder(
         image_size = image_size,
         num_image_tiles = num_image_tiles,
         optimizer = optimizer,
+        num_workers = num_workers,
         fmap_max = fmap_max,
         transparent = transparent,
         greyscale = greyscale,
         lr = learning_rate,
         save_every = save_every,
         evaluate_every = evaluate_every,
-        trunc_psi = trunc_psi,
         aug_prob = aug_prob,
         aug_types = cast_list(aug_types),
         dataset_aug_prob = dataset_aug_prob,
